from spectacle.modeling import Spectral1D, OpticalDepth1D
import astropy.units as u
from matplotlib import pyplot as plt
import numpy as np
from astropy.visualization import quantity_support
quantity_support()  # doctest: +IGNORE_OUTPUT

# We'll go ahead and compose a spectrum in velocity space of two HI line
# profiles, with one offset by :math:`30 \tfrac{km}{s}`.

line1 = OpticalDepth1D(lambda_0=1216 * u.AA, v_doppler=7 * u.km/u.s, column_density=13, delta_v=0 * u.km/u.s)
line2 = OpticalDepth1D("HI1216", delta_v=30 * u.km/u.s,  v_doppler=12 * u.km/u.s, column_density=13)

spec_mod = Spectral1D([line1, line2], continuum=1, output='flux')

x = np.linspace(-200, 200, 1000) * u.km / u.s
y = spec_mod(x)

# Now, print the statistics on this absorption region.

region_stats = spec_mod.region_stats(x, rest_wavelength=1216 * u.AA, abs_tol=0.05)
print(region_stats)   # doctest: +IGNORE_OUTPUT
# region_start        region_end     rest_wavelength          ew                dv90               fwhm
# km / s             km / s           Angstrom          Angstrom            km / s            Angstrom
# ------------------- ------------------ --------------- ------------------- ----------------- --------------------
# -12.612612612612594 48.648648648648674          1216.0 0.12297380252108686 46.44644644644646 0.056842794376279926

# Plot to show the found bounds of the contiguous absorption region.

f, ax = plt.subplots()  # doctest: +IGNORE_OUTPUT
ax.axhline(0.95, linestyle='--', color='k', alpha=0.5)  # doctest: +IGNORE_OUTPUT
for row in region_stats:
   ax.axvline(row['region_start'].value, color='r', alpha=0.5)  # doctest: +IGNORE_OUTPUT
   ax.axvline(row['region_end'].value, color='r', alpha=0.5)  # doctest: +IGNORE_OUTPUT
ax.step(x, y)  # doctest: +IGNORE_OUTPUT
