from astropy import units as u
import numpy as np
from matplotlib import pyplot as plt
from spectacle.modeling import Spectral1D, OpticalDepth1D
from spectacle.fitting.line_finder import LineFinder1D
line1 = OpticalDepth1D("HI1216", v_doppler=20 * u.km/u.s, column_density=16)
line2 = OpticalDepth1D("OVI1032", v_doppler=60 * u.km/u.s, column_density=16)
spec_mod = Spectral1D([line1, line2], continuum=0, output='optical_depth')
x = np.linspace(1000, 1300, 10000) * u.Unit('Angstrom')
y = spec_mod(x)

line_finder = LineFinder1D(ions=["HI1216", "OVI1032"], continuum=0, output='optical_depth')
finder_spec_mod = line_finder(x, y)
finder_y = finder_spec_mod(x)
mask1 = (x.value >= line1.lambda_0.value - 2) & (x.value <= line1.lambda_0.value + 2)
mask2 = (x.value >= line2.lambda_0.value - 2) & (x.value <= line2.lambda_0.value + 2)
f, (ax1, ax2) = plt.subplots(1, 2, sharey=True)   # doctest: +SKIP
ax1.step(x[mask2], y[mask2], label="Original Data")  # doctest: +SKIP
ax1.step(x[mask2], finder_y[mask2], label="Finder Result")  # doctest: +SKIP
ax2.step(x[mask1], y[mask1])  # doctest: +SKIP
ax2.step(x[mask1], finder_y[mask1])  # doctest: +SKIP
ax1.set_title("OVI1032")  # doctest: +SKIP
ax2.set_title("HI1216")  # doctest: +SKIP
f.add_subplot(111, frameon=False)  # doctest: +SKIP
plt.xlabel("Wavelength [Angstrom]")  # doctest: +SKIP
plt.tick_params(labelcolor='none', top=False, bottom=False, left=False, right=False)  # doctest: +SKIP
f.legend()  # doctest: +SKIP
f.subplots_adjust(wspace=0)  # doctest: +SKIP
