from astropy import units as u
import numpy as np
from matplotlib import pyplot as plt
from spectacle.modeling import Spectral1D, OpticalDepth1D

line = OpticalDepth1D("HI1216", v_doppler=50 * u.km/u.s, column_density=14)
line2 = OpticalDepth1D("HI1216", delta_v=100 * u.km/u.s)

spec_mod = Spectral1D([line, line2], continuum=1, output='flux')
x = np.linspace(-500, 500, 1000) * u.Unit('km/s')

flux = spec_mod(x)
flux_dec = spec_mod.as_flux_decrement(x)
tau = spec_mod.as_optical_depth(x)

f, (ax1, ax2, ax3) = plt.subplots(3, 1, sharex=True)
ax1.set_title("Flux") # doctest: +IGNORE_OUTPUT
ax1.step(x, flux) # doctest: +IGNORE_OUTPUT
ax2.set_title("Flux Decrement") # doctest: +IGNORE_OUTPUT
ax2.step(x, flux_dec) # doctest: +IGNORE_OUTPUT
ax3.set_title("Optical Depth") # doctest: +IGNORE_OUTPUT
ax3.step(x, tau) # doctest: +IGNORE_OUTPUT
ax3.set_xlabel('Velocity [km/s]') # doctest: +IGNORE_OUTPUT
f.tight_layout()
