from astropy import units as u
import numpy as np
from matplotlib import pyplot as plt
from spectacle.modeling import Spectral1D, OpticalDepth1D

line1 = OpticalDepth1D("HI1216", v_doppler=500 * u.km/u.s, column_density=14)
line2 = OpticalDepth1D("OVI1032", v_doppler=500 * u.km/u.s, column_density=15)

spec_mod = Spectral1D([line1, line2], continuum=1, z=0, output='flux')
spec_mod_with_z = Spectral1D([line1, line2], continuum=1, z=0.05, output='flux')

x = np.linspace(1000, 1300, 1000) * u.Unit('Angstrom')

f, ax = plt.subplots()  # doctest: +SKIP
ax.step(x, spec_mod(x), label="k$z=0$") # doctest: +SKIP
ax.step(x, spec_mod_with_z(x), label="$z=0.05$")  # doctest: +SKIP
ax.set_xlabel("Wavelength [Angstrom]")  # doctest: +SKIP
f.legend(loc=0)  # doctest: +SKIP
